@@ -203,6 +203,8 @@ void audio_device_close(void)
     if (handle != NULL) {
         int err;
 
+	printf("Closing the ALSA audio device\n") ;
+
         err = snd_pcm_drop(handle);
         if (err < 0) {
             perr("audio_device_close: snd_pcm_drop", err);
@@ -224,7 +226,8 @@ long audio_device_processed_bytes(void)
     int err = snd_pcm_delay(handle, &frame_delay);
 
     if (err < 0) {
-        perr("audio_device_processed_bytes: snd_pcm_delay", err);
+        fprintf(stderr, "audio_device_processed_bytes: snd_pcm_delay %s\n", snd_strerror(err));
+	return snd_pcm_frames_to_bytes(handle, written_frames);
     }
 
     /*     printf("audio_device_processed_bytes:%d\n", */
@@ -246,10 +249,11 @@ int audio_device_best_buffer_size(int playback_bytes_per_block)
         perr("audio_device_best_buffer_size: snd_pcm_status", err);
         return 0;
     }
+
     frames = snd_pcm_status_get_avail(status);
 
-    /*     printf("audio_device_best_buffer_size:%d (frames:%ld)\n", */
-    /*            snd_pcm_frames_to_bytes(handle, frames), frames); */
+/*      printf("audio_device_best_buffer_size:%d (frames:%ld)\n",  */
+/*  	snd_pcm_frames_to_bytes(handle, frames), frames);  */
 
     return snd_pcm_frames_to_bytes(handle, frames);
 }
