@@ -34,12 +34,7 @@
 #include "audio_device.h"
 #include "soundfile.h"
 
-#define NOTHING 0x00
-#define MONITOR 0x01
-#define RECORDING  0x02
-#define PLAYBACK  0x04
-
-int audio_state = 0 ;
+int audio_state = AUDIO_IS_IDLE ;
 int wavefile_fd = -1 ;
 long audio_bytes_written ;
 int rate = 44100 ;
@@ -181,9 +176,8 @@ long first_playback_sample ;
 long set_playback_cursor_position(struct view *v, long millisec_per_visual_frame)
 {
     long first, last ;
-    extern int audio_playback ;
 
-    if(audio_playback == TRUE) {
+    if(audio_state == AUDIO_IS_PLAYBACK) {
 	long bytes = audio_device_processed_bytes()-looped_count*playback_total_bytes ;
 	get_region_of_interest(&first, &last, v) ;
 
@@ -218,8 +212,6 @@ long start_playback(char *output_device, struct view *v, struct sound_prefs *p,
 	return 1 ;
     }
 
-    config_audio_device(p->rate,  p->playback_bits, p->stereo) ;
-
     get_region_of_interest(&first, &last, v) ;
 
 /*      g_print("first is %ld\n", first) ;  */
@@ -234,6 +226,12 @@ long start_playback(char *output_device, struct view *v, struct sound_prefs *p,
     playback_samples = p->rate*seconds_per_block ;
     playback_bytes_per_block = playback_samples*PLAYBACK_FRAMESIZE ;
 
+    //  This was moved down 8 lines to make it work in OS X.  Rob
+    config_audio_device(p->rate, p->playback_bits, p->stereo);	//Set up the audio device.
+    //stereo is 1 if it is stereo
+    //playback_bits is the number of bits per sample
+    //rate is the number of samples per second
+
     BUFSIZE = audio_device_best_buffer_size(playback_bytes_per_block);
 
     playback_bytes_per_block = BUFSIZE ;
@@ -249,7 +247,7 @@ long start_playback(char *output_device, struct view *v, struct sound_prefs *p,
     playback_samples_remaining = (last-first+1) ;
     playback_total_bytes = playback_samples_remaining*PLAYBACK_FRAMESIZE ;
 
-    audio_state = PLAYBACK ;
+    audio_state = AUDIO_IS_PLAYBACK ;
 
     sf_seek(sndfile, playback_position, SEEK_SET) ;
 
@@ -422,10 +420,7 @@ void save_selection_as_wavfile(char *filename_new, struct view *v)
     {
 	long n_copied  ;
 
-/* #define TMPBUFSIZE     200000 */
-#ifndef TRUNCATE_OLD
 #define TMPBUFSIZE     (SBW*1000)
-#endif    
 	unsigned char buf[TMPBUFSIZE] ;
 	long framebufsize = (TMPBUFSIZE/FRAMESIZE) * FRAMESIZE ;
 
@@ -434,6 +429,10 @@ void save_selection_as_wavfile(char *filename_new, struct view *v)
 	for(n_copied = 0 ; n_copied < total_bytes ; n_copied += framebufsize) {
 	    long n_to_copy = framebufsize ;
 
+#ifdef MAC_OS_X /* MacOSX */
+	    usleep(2) ; // prevents segfault on OSX, who knows, something to do with status bar update...
+#endif
+
 	    update_status_bar((gfloat)(n_copied)/(gfloat)(total_bytes),STATUS_UPDATE_INTERVAL,FALSE) ;
 
 	    if(n_copied + n_to_copy > total_bytes) n_to_copy = total_bytes - n_copied ;
@@ -458,6 +457,8 @@ int is_valid_audio_file(char *filename)
     SNDFILE *sndfile ;
     SF_INFO sfinfo ;
 
+    sfinfo.format = 0 ;
+
     if((sndfile = sf_open(filename, SFM_READ, &sfinfo)) != NULL) {
 	sf_close(sndfile) ;
 	return 1 ;
@@ -486,8 +487,9 @@ struct sound_prefs open_wavefile(char *filename, struct view *v)
 	/* Open failed so print an error message. */
 
 	char buf[80] ;
-	sprintf(buf, "Failed to open  %s", filename) ;
+	sprintf(buf, "Failed to open  %s, no permissions or unknown audio format", filename) ;
 	warning(buf) ;
+	wfh.successful_open = FALSE ;
 	return wfh ;
 
         /* Print the error message from libsndfile. */
@@ -768,6 +770,8 @@ void flush_wavefile_data(void)
     fsync(wavefile_fd) ;
 }
 
+/* process_audio for mac_os_x is found in the audio_osx.c */
+#ifndef MAC_OS_X
 int process_audio(gfloat *pL, gfloat *pR)
 {
     int len = 0 ;
@@ -785,16 +789,16 @@ int process_audio(gfloat *pL, gfloat *pR)
     *pR = 0.0 ;
 	
 
-    if(audio_state == NOTHING) {
+    if(audio_state == AUDIO_IS_IDLE) {
 	d_print("process_audio says NOTHING is going on.\n") ;
 	return 1 ;
     }
 
-    if(audio_state == RECORDING) {
+    if(audio_state == AUDIO_IS_RECORDING) {
 	if((len = audio_device_read(audio_buffer, BUFSIZE)) == -1) {
 	    warning("Error on audio read...") ;
 	}
-    } else if(audio_state == PLAYBACK) {
+    } else if(audio_state == AUDIO_IS_PLAYBACK) {
         len = audio_device_nonblocking_write_buffer_size(
             MAXBUFSIZE, playback_samples_remaining*PLAYBACK_FRAMESIZE);
 
@@ -872,17 +876,17 @@ int process_audio(gfloat *pL, gfloat *pR)
     *pL = (gfloat) maxl / maxpossible ;
     *pR = (gfloat) maxr / maxpossible ;
 
-    if(audio_state == RECORDING) {
+    if(audio_state == AUDIO_IS_RECORDING) {
 	len = write(wavefile_fd, audio_buffer, len) ;
 	audio_bytes_written += len ;
-    } else if(audio_state == PLAYBACK) {
+    } else if(audio_state == AUDIO_IS_PLAYBACK) {
 	len = audio_device_write(p_char, len) ;
 	playback_position += n_read ;
 	playback_samples_remaining -= n_read ;
 	if(playback_samples_remaining < 1) {
 	    extern int audio_is_looping ;
 	    if(audio_is_looping == FALSE) {
-		audio_state = PLAYBACK ;
+		audio_state = AUDIO_IS_PLAYBACK ;
 		audio_playback = FALSE ;
 		g_print("Stop playback with playback_samples_remaining:%ld\n", playback_samples_remaining) ;
 		return 1 ;
@@ -897,6 +901,7 @@ int process_audio(gfloat *pL, gfloat *pR)
     }
     return 0 ;
 }
+#endif
 
 void stop_playback(int force)
 {
@@ -921,6 +926,6 @@ void stop_playback(int force)
 	usleep(100) ;
     }
 
-    audio_state = NOTHING ;
+    audio_state = AUDIO_IS_IDLE ;
     audio_device_close() ;
 }
