@@ -471,23 +471,18 @@ char *do_declick_fft(struct sound_prefs *p, long first_sample, long last_sample,
 struct click_data *clicks, int iterate_flag)
 {
     static char results_buf[200] ;
-    long min_sample, max_sample ;
-    long sample ;
     long window_first ;
     long i,k ;
-    long n_samples = last_sample - first_sample + 1 ;
     int FFT_SIZE = 64 ;
-    int n_repaired[2] , n_this_pass, n_last_pass;
+    int n_repaired[2] , n_this_pass ;
     int n_not_repaired[2] ;
-    int n ;
-    int offset0,offsetF;
     char max_exceeded_notice = 0 ;
 #define FFT_WINDOW 1000
     char level[2][2*FFT_WINDOW+1][DECLICK_MAX_FFT] ;
 #ifdef HAVE_FFTW3
     FFTW(plan) pLeft, pRight ;
 #else /* HAVE_FFTW3 */
-    rfftw_plan p ;
+    rfftw_plan fftw_p ;
 #endif /* HAVE_FFTW3 */
 
     fftw_real data[2][2*FFT_WINDOW+1] ;
@@ -497,7 +492,6 @@ struct click_data *clicks, int iterate_flag)
 
     int in_click ;
     int window_size  = FFT_WINDOW * MIN((p->rate/44100.0),2) ;
-    int window_overlap  = WINDOW_OVERLAP * MIN((p->rate/44100.0),2) ;
     int window_step ;
     int channel ;
     int done = 0 ;
@@ -525,7 +519,7 @@ struct click_data *clicks, int iterate_flag)
     pLeft = FFTW(plan_r2r_1d)(FFT_SIZE, data[0], out, FFTW_R2HC, FFTW_ESTIMATE);
     pRight = FFTW(plan_r2r_1d)(FFT_SIZE, data[1], out, FFTW_R2HC, FFTW_ESTIMATE);
 #else /* HAVE_FFTW3 */
-    p = rfftw_create_plan(FFT_SIZE, FFTW_REAL_TO_COMPLEX, FFTW_ESTIMATE);
+    fftw_p = rfftw_create_plan(FFT_SIZE, FFTW_REAL_TO_COMPLEX, FFTW_ESTIMATE);
 #endif /* HAVE_FFTW3 */
 
     for(k = 0 ; k < FFT_SIZE ; k++) {
@@ -533,9 +527,7 @@ struct click_data *clicks, int iterate_flag)
     }
 
     for(window_first = first_sample ; !done && window_first < last_sample ; window_first += window_step ) {
-	int nclicks_not_repaired_start = clicks->n_clicks ;
 	int clicks_repaired = 1 ;
-	int loop_flag = 1 ;
 	int min_sample,max_sample ;
 
 	if(window_first + window_size > last_sample) {
@@ -565,6 +557,7 @@ struct click_data *clicks, int iterate_flag)
 	    for (channel = 0; channel < 2; channel++) {
 		double min_p = 1.e30, max_p = -1.e30 ;
 		if(! ((channel+1) & channel_mask) ) continue ;
+
 #ifdef HAVE_FFTW3
 		if (channel == 0)
 		   FFTW(execute)(pLeft);
@@ -572,18 +565,20 @@ struct click_data *clicks, int iterate_flag)
 		   FFTW(execute)(pRight);
 #else /* HAVE_FFTW3 */
 		if (channel == 0)
-		   rfftw_one(p, left, out);
+		   rfftw_one(fftw_p, data[0], out);
 		else
-		   rfftw_one(p, right, out);
+		   rfftw_one(fftw_p, data[1], out);
 #endif /* HAVE_FFTW3 */
+
 		power_spectrum[0] = out[0]*out[0];  /* DC component */
+
 		for (k = 1; k < (FFT_SIZE+1)/2; ++k)  /* (k < FFT_SIZE/2 rounded up) */
 		    power_spectrum[k] = out[k]*out[k] + out[FFT_SIZE-k]*out[FFT_SIZE-k];
+
 		if (FFT_SIZE % 2 == 0) /* N is even */
 		    power_spectrum[FFT_SIZE/2] = (out[FFT_SIZE/2]*out[FFT_SIZE/2]);  /* Nyquist freq. */
 
 		for(k = 1 ; k <= FFT_SIZE/2 ; k++) {
-		    int y ;
 		    double p = 10.0*log10(power_spectrum[k]) ;
 
 		    if(p < -127.0) p = -127.0 ;
@@ -600,9 +595,9 @@ struct click_data *clicks, int iterate_flag)
 	for(channel = 0 ; channel < 2 ; channel++) {
 	    double mean_level[FFT_SIZE] ;
 	    double offset[FFT_WINDOW*2+1] ;
-	    double hgt_sum ;
+	    double hgt_sum = 0 ;
 	    double mean, stderr, var, cv, stddev ;
-	    long click_start, click_end ;
+	    long click_start = 0 ;
 
 	    if(! ((channel+1) & channel_mask) ) continue ;
 
@@ -718,7 +713,7 @@ struct click_data *clicks, int iterate_flag)
 	FFTW(destroy_plan)(pLeft);
 	FFTW(destroy_plan)(pRight);
     #else /* HAVE_FFTW3 */
-	rfftw_destroy_plan(p);
+	rfftw_destroy_plan(fftw_p);
     #endif /* HAVE_FFTW3 */
 
 
