@@ -26,8 +26,29 @@
 #include <math.h>
 #include <float.h>
 
-#include <sys/timeb.h>
+#include <unistd.h>
+#include <sys/time.h>
 
+//struct timeb start_time, middle_time, end_time ;
+struct timeval start_time, middle_time, end_time ;
+struct timezone tzp;
+
+void start_timer(void)
+{
+        gettimeofday(&start_time,&tzp);
+}
+
+void stop_timer(char *message)
+{
+    gettimeofday(&end_time,&tzp) ;
+    {
+	double fstart = start_time.tv_sec + (double)start_time.tv_usec/1000000.0 ;
+	double fend = end_time.tv_sec + (double)end_time.tv_usec/1000000.0 ;
+	fprintf(stderr, "%s in %7.3lf real seconds\n", message, fend-fstart) ;
+    }
+}
+
+#ifdef OLD_TIMER
 struct timeb start_time, middle_time, end_time ;
 
 void start_timer(void)
@@ -45,6 +66,7 @@ void stop_timer(char *message)
 	fprintf(stderr, "%s in %7.3lf real seconds\n", message, fend-fstart) ;
     }
 }
+#endif
 
 
 
@@ -493,6 +515,10 @@ int denoise(struct sound_prefs *pPrefs, struct denoise_prefs *pDnprefs, long noi
 	    n = read_fft_real_wavefile_data(left,  right, current, current+pDnprefs->FFT_SIZE-1) ;
 	    if(n < pDnprefs->FFT_SIZE) break ; /*  hit the end of all data? */
 
+#ifdef MAC_OS_X
+	    // This usleep fixes a segfault on OS X.  Rob Frohne
+	    usleep(2);
+#endif
 	    update_status_bar(p,STATUS_UPDATE_INTERVAL,FALSE) ;
 
 	    /*
@@ -579,7 +605,7 @@ int denoise(struct sound_prefs *pPrefs, struct denoise_prefs *pDnprefs, long noi
 
 int print_noise_sample(struct sound_prefs *pPrefs, struct denoise_prefs *pDnprefs, long noise_start, long noise_end)
 {
-    int i, k ;
+    int k ;
     FILE *fp ;
 
     fftw_real left_noise_max[DENOISE_MAX_FFT], right_noise_max[DENOISE_MAX_FFT], left_noise_avg[DENOISE_MAX_FFT] ;
@@ -599,6 +625,8 @@ int print_noise_sample(struct sound_prefs *pPrefs, struct denoise_prefs *pDnpref
     }
 
     fclose(fp) ;
+
+    return 0 ;
 }
 
 void get_noise_sample(struct sound_prefs *pPrefs, struct denoise_prefs *pDnprefs, long noise_start, long noise_end,
