@@ -54,10 +54,8 @@
 #include "icons/filter.xpm"
 #include "icons/noise_sample.xpm"
 #include "icons/remove_noise.xpm"
-#include "icons/cut.xpm"
 #include "icons/start.xpm"
 #include "icons/stop.xpm"
-#include "icons/undo.xpm"
 #include "icons/zoom_sel.xpm"
 #include "icons/zoom_in.xpm"
 #include "icons/zoom_out.xpm"
@@ -159,6 +157,17 @@ void d_print(char *fmt, ...)
     }
 }
 
+static int audio_debug = 0 ;
+
+void audio_debug_print(char *fmt, ...)
+{
+    if (audio_debug) {
+	va_list ap;
+	va_start(ap, fmt);
+	vprintf(fmt, ap);
+    }
+}
+
 char *sample_to_time_text(long i, int rate, char *prefix, char *buf)
 {
     int m, s, ms;
@@ -634,9 +643,35 @@ void manual_declick(GtkWidget * widget, gpointer data)
 	get_region_of_interest(&first, &last, &audio_view);
 
 	if (last - first > 299) {
+	    char msg_buf[1000] ;
+	    double n = last-first+1 ;
+	    double a = 100 ;
+	    double elements = (
+				    n +
+				    (n-a) * n +
+				    (n-a) * n +
+				    (n-a) * n +
+				    (n-a) * (n-a) +
+				    (n-a) * (n-a) +
+				    n * n
+				) ;
+	    double bytes = elements * sizeof(double) / (double) (1 << 20) ;
+	    char *units = "Megabytes" ;
+
+	    if(bytes > 1000) {
+		bytes /= (double) 1024 ;
+		units = "Gigabytes" ;
+	    }
+
+	    if(bytes > 1000) {
+		bytes /= (double) 1024 ;
+		units = "Terabytes" ;
+	    }
+
+	    sprintf(msg_buf, "Repairing > 300 samples  may cause a crash\nYou have selected %lg samples, which will require about %8.0lf %s of memory and a long time.",
+			    n, bytes, units ) ;
 	    doit = FALSE;
-	    if (!yesno
-		("Declicking > 300 samples may cause a crash, continue?"))
+	    if (!yesno(msg_buf))
 		doit = TRUE;
 	}
 
@@ -981,7 +1016,7 @@ gint play_a_block(gpointer data)
 	set_playback_cursor_position(&audio_view, prev_cursor_millisec);
 
     if (bytes_left < 10 && !audio_is_looping) {	/* the  "10" is to allow some error in the audio driver */
-/*  	g_print("play_a_block is stopping the playback_timer.\n") ;  */
+	audio_debug_print("play_a_block is stopping the playback_timer.\n") ;
 	stop_playback_force = 0 ;
 	stop_all_playback_functions(NULL, NULL) ;
 	stop_playback_force = 1 ;
@@ -995,6 +1030,7 @@ gint update_cursor(gpointer data)
 {
     long cursor_samples_per_pixel;
     long cursor_millisec;
+    audio_debug_print("update_cursor with audio_playback:%d\n", audio_playback) ;
 
     if (audio_playback == TRUE) {
 	cursor_samples_per_pixel =
@@ -1015,17 +1051,19 @@ gint update_cursor(gpointer data)
 
 	set_playback_cursor_position(&audio_view, prev_cursor_millisec);
 	main_redraw(TRUE, TRUE);
-/*  	g_print(".") ;  */
+	audio_debug_print(".\n") ;
     } else {
 	long last, first;
+
 	get_region_of_interest(&first, &last, &audio_view);
+
 	if (audio_view.cursor_position < last) {
 	    set_playback_cursor_position(&audio_view,
 					 prev_cursor_millisec);
 	    main_redraw(TRUE, TRUE);
-/*  	    g_print("?") ;  */
+	    audio_debug_print("?\n") ;
 	} else {
-/*  	    g_print("update_cursor is stopping cursor_timer\n") ;  */
+	    audio_debug_print("\nupdate_cursor is stopping cursor_timer\n") ;
 	    cursor_playback = FALSE;
 	    gtk_timeout_remove(cursor_timer);
 	    stop_playback_force = 0 ;
@@ -1042,15 +1080,18 @@ gint update_cursor(gpointer data)
 
 /* This is a callback function. The data arguments are ignored
 * in this example. More on callbacks below. */
-void start(GtkWidget * widget, gpointer data)
+void start_gwc_playback(GtkWidget * widget, gpointer data)
 {				/* Play audio */
     long millisec_per_block;
 
+    audio_debug_print("entering start_gwc_playback with audio_playback=%d\n", audio_playback) ;
+
     if (file_is_open == TRUE && file_processing == FALSE
 	&& audio_playback == FALSE && cursor_playback == FALSE) {
 	audio_playback = TRUE;
 
 	playback_samples_per_block = start_playback(audio_device, &audio_view, &prefs, 0.10, 0.25);
+	audio_debug_print("playback_samples_per_block=%ld\n", playback_samples_per_block) ;
 
 	if (audio_playback == TRUE) {
 	    millisec_per_block =
@@ -1059,8 +1100,12 @@ void start(GtkWidget * widget, gpointer data)
 		(millisec_per_block - 5) * prefs.rate / 1000;
 	    {
 		long margin = 50;
+
 		if (millisec_per_block < 100)
 		    margin = millisec_per_block / 2;
+
+		audio_debug_print("start_gwc_playback starting playback timers\n") ;
+
 		playback_timer =
 		    gtk_timeout_add(millisec_per_block - margin,
 				    play_a_block, NULL);
@@ -1077,7 +1122,7 @@ void start(GtkWidget * widget, gpointer data)
 	}
     }
 
-    g_print("leaving start with audio_playback=%d\n", audio_playback) ;
+    audio_debug_print("leaving start_gwc_playback with audio_playback=%d\n", audio_playback) ;
 
     audio_is_looping = FALSE ;
 }
@@ -1407,14 +1452,14 @@ gboolean  key_press_cb(GtkWidget * widget, GdkEventKey * event, gpointer data)
     switch (event->keyval) {
 	case GDK_space:
 	    if (cursor_playback == FALSE)
-		start(widget, data);
+		start_gwc_playback(widget, data);
 	    else {
 		stop_all_playback_functions(widget, data);
 	    }
 	    break;
 	case GDK_l:
 	    if (cursor_playback == FALSE) {
-		start(widget, data);
+		start_gwc_playback(widget, data);
 		audio_is_looping = TRUE ;
 	    } else {
 		audio_is_looping = FALSE ;
@@ -1509,7 +1554,7 @@ void destroy(GtkWidget * widget, gpointer data)
 
 void about(GtkWidget * widget, gpointer data)
 {
-    const gchar *authors[] = { "Jeffrey J. Welty", "James Tappin", "Ian Leonard", "Bill Jetzer", "Charles Morgon", "Frank Freudenberg", "Thiemo Gehrke", NULL };
+    const gchar *authors[] = { "Jeffrey J. Welty", "James Tappin", "Ian Leonard", "Bill Jetzer", "Charles Morgon", "Frank Freudenberg", "Thiemo Gehrke", "Rob Frohne", NULL };
     gtk_widget_show(gnome_about_new("Gnome Wave Cleaner",
 				    VERSION,
 				    "Copyright 2001,2002,2003,2004,2005 Redhawk.org",
@@ -1885,7 +1930,7 @@ GnomeUIInfo edit_menu[] = {
 		     declick_weak, declick_w_xpm),
 
     GNOMEUIINFO_ITEM("    Declick Manual",
-		     "Apply declicking algorithm to  current view or selection",
+		     "Apply LSAR signal estimation  to current view or selection",
 		     manual_declick, declick_m_xpm),
 
     GNOMEUIINFO_ITEM_ACCEL("    Decrackle",
@@ -2034,7 +2079,7 @@ GnomeUIInfo menubar[] = {
 GnomeUIInfo transport_toolbar_info[] = {
     GNOMEUIINFO_ITEM("Start",
 		     "Playback the selected or current view of audio",
-		     start, start_xpm),
+		     start_gwc_playback, start_xpm),
     GNOMEUIINFO_ITEM("Stop", "Stop audio playback",
 		     stop_all_playback_functions, stop_xpm),
 
@@ -2085,7 +2130,7 @@ GnomeUIInfo edit_toolbar_info[] = {
 		     declick_weak, declick_w_xpm),
 
     GNOMEUIINFO_ITEM("Declick Manual",
-		     "Apply declicking algorithm to  current view or selection",
+		     "Apply LSAR signal estimation to current view or selection",
 		     manual_declick, declick_m_xpm),
 
     GNOMEUIINFO_ITEM("Decrackle",
