@@ -169,7 +169,7 @@ void cdrdao_toc_info(char *filename)
           if (init == NULL) {
              init = song_info[i].init;
           }
-          song_widget[j][i] = add_number_entry_with_label(init, buf, song_table, row++) ;
+	  song_widget[j][i] = add_number_entry_with_label(init, buf, song_table, row++) ;
        }
     }
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dlg)->vbox), dialog_table, TRUE, TRUE, 0);
@@ -353,7 +353,10 @@ void add_song_marker(void)
       for (j = num_song_markers - 1; j >= i;  j--) {
          song_markers[j+1] = song_markers[j];
       }
-      song_markers[i] = (loc / SONG_BLOCK_LEN) * SONG_BLOCK_LEN;
+      /* commenting out -- cdrdao will automatically pad the audio data
+         so this seems an unnecessary constraint.  jw 1/5/2005 */
+      //song_markers[i] = (loc / SONG_BLOCK_LEN) * SONG_BLOCK_LEN;
+      song_markers[i] = loc ;
       num_song_markers++; 
       main_redraw(FALSE, TRUE);
    }
